@@ -1,7 +1,7 @@
 /*
  * This file is part of budgie-desktop
  *
- * Copyright © 2020 Budgie Desktop Developers
+ * Copyright © 2021 Budgie Desktop Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,11 +22,12 @@ typedef struct _CarbonChild {
 
 	int preferredSize;
 	Window iconWindow;
+	GdkWindow* widgetWindow;
 
 	char* wmclass;
 
 	bool parentRelativeBg;
-	bool isComposited;
+	bool hasAlpha;
 } CarbonChild;
 
 typedef struct _CarbonChildClass {
@@ -34,13 +35,11 @@ typedef struct _CarbonChildClass {
 } CarbonChildClass;
 
 
-
 #define CARBON_TYPE_CHILD (carbon_child_get_type())
 #define CARBON_CHILD(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), CARBON_TYPE_CHILD, CarbonChild))
 #define CARBON_IS_CHILD(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), CARBON_TYPE_CHILD))
 
 
-
 GType carbon_child_get_type(void);
 
 CarbonChild* carbon_child_new(int, bool, GdkScreen*, Window);
